import { addRegulation, getRegulationById } from '@/services/regulation';
import { queryDict } from '@/utils/request';
import { PageContainer, ProForm, ProFormSelect, ProFormText } from '@ant-design/pro-components';
import { Card, Col, message, Row, Space } from 'antd';
import { useNavigate, useSearchParams } from 'react-router-dom';
import { useEffect, useRef, useState } from 'react';

export default (props) => {
  const [searchParams, setSearchParams] = useSearchParams();
  const id = searchParams.get('id');
  const formRef = useRef();
  const navigate = useNavigate();

  useEffect(() => {
    if (id) {
      getRegulationById(id).then((res) => {
        formRef.current.setFieldsValue(res);
      });
    }
  }, [id]);

  const onFinish = async (values) => {
    console.log(values);

    // if (id) {
    //添加,修改
    addRegulation({ ...values, id }).then((res) => {
      message.success('成功');
      navigate(-1);
    });
    return false;
  };

  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={'horizontal'}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 16 }}
          onFinish={onFinish}
          submitter={{
            searchConfig: {
              resetText: '返回',
            },
            onReset: () => navigate(-1),
            render: (props, doms) => {
              return (
                <Row>
                  <Col span={8} offset={8}>
                    <Space>{doms}</Space>
                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormText
            name="detail"
            label="发布内容"
            placeholder="请输入发布内容"
            rules={[{ required: true, message: '请输入发布内容' }]}
            allowClear={false}
            width={460}
          />
          <ProFormText
            name="title"
            label="内容名称"
            placeholder="请输入内容名称"
            rules={[{ required: true, message: '请输入内容名称' }]}
            allowClear={false}
            width={460}
          />
        </ProForm>
      </Card>
    </PageContainer>
  );
}